Tournament Objects
========================================

TournamentPlayer Reference
----------------------------------------------------------
.. automodule:: novauniverse.objects.tournaments.tournament_player
   :members:
   :undoc-members:
   :show-inheritance:

TournamentTeam Reference
--------------------------------------------------------
.. automodule:: novauniverse.objects.tournaments.tournament_team
   :members:
   :undoc-members:
   :show-inheritance: